"""
Drun 项目脚手架模板集合。

提供 `drun init` 命令需要的所有示例和模板内容。
"""

from .templates import (
    CONVERTS_README,
    CSV_DATA_TESTCASE,
    CSV_DATA_TESTSUITE,
    CSV_USERS_SAMPLE,
    DB_ASSERT_TESTCASE,
    DEMO_TESTCASE,
    DEMO_TESTSUITE,
    ENV_TEMPLATE,
    GITIGNORE_TEMPLATE,
    GITKEEP_CONTENT,
    HEALTH_TESTCASE,
    HOOKS_TEMPLATE,
    SAMPLE_CURL,
    SAMPLE_HAR,
    SAMPLE_OPENAPI,
    SAMPLE_POSTMAN_COLLECTION,
    SAMPLE_POSTMAN_ENVIRONMENT,
    README_TEMPLATE,
    STREAM_TESTCASE,
)

__all__ = [
    "CONVERTS_README",
    "CSV_DATA_TESTCASE",
    "CSV_DATA_TESTSUITE",
    "CSV_USERS_SAMPLE",
    "DB_ASSERT_TESTCASE",
    "DEMO_TESTCASE",
    "DEMO_TESTSUITE",
    "ENV_TEMPLATE",
    "GITIGNORE_TEMPLATE",
    "GITKEEP_CONTENT",
    "HEALTH_TESTCASE",
    "HOOKS_TEMPLATE",
    "README_TEMPLATE",
    "SAMPLE_CURL",
    "SAMPLE_HAR",
    "SAMPLE_OPENAPI",
    "SAMPLE_POSTMAN_COLLECTION",
    "SAMPLE_POSTMAN_ENVIRONMENT",
    "STREAM_TESTCASE",
]
